# coding=utf-8
# Copyright 2017 Flowdas Inc. <prospero@flowdas.com>
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
"""
Oliver 의 설정을 제공하는 모듈.

``Oliverfile`` 모듈은 이 모듈의 값들을 오버라이드한다.

``Oliverfile`` 이외의 장소에서는 값을 읽기만 해야 한다. 값을 변경할 경우의 동작은 정의되지 않았다.

Since version 0.2.
"""
from __future__ import absolute_import

DEBUG = False
"""디버깅 출력이 활성화되면 True 로 설정된다.

이 파라미터는 ``Oliverfile`` 이 실행될 때 미리 정의되어 있고, 수정할 수 없다.

Since version 0.2.
"""

OLIVERFILE = 'Oliverfile'
"""oliverfile 의 절대 경로.

이 파라미터는 ``Oliverfile`` 이 실행될 때 미리 정의되어 있고, 수정할 수 없다.

Since version 0.2.
"""

PYTHONPATH = []
"""파이썬 경로에 포함시킬 디렉토리들의 목록.

Since version 0.2.
"""

ENV = {}
"""설정할 환경 변수들.

Since version 0.2.
"""

CHDIR = '.'
"""실행시에 chdir 할 디렉토리.

Since version 0.2.
"""

LOGLEVEL = 'info'
"""로그 수준.

Since version 0.2.
"""

LOGFILE = 'Oliver.log'
"""로그가 기록되는 파일의 경로.

Since version 0.2.
"""

SERVER_ADDR = '127.0.0.1'
"""서버의 listening socket 이 bind 하는 인터페이스.

개발 모드에서는 무시된다.

Since version 0.2.
"""

SERVER_PORT = 8000
"""서버가 listening 하는 socket 의 port

Since version 0.2.
"""

BACKLOG = 2048
"""최대 pending connection 의 개수.

Since version 0.2.
"""

WORKER_CONNECTIONS = 10000
"""최대 동시 접속 수.

Since version 0.2.
"""

PIDFILE = 'Oliver.pid'
"""서버의 ``pid`` 가 기록되는 파일의 경로.

``None`` 이면 ``pid`` 를 기록하지 않는다.

Since version 0.2.
"""

OMX = '/__oliver__'
"""OMX 가 제공되는 URI.

``None`` 이면 OMX 가 제공되지 않는다.

Since version 0.2.
"""

OMX_ALLOW = '*'
"""OMX 요청을 허락할 클라이언트의 IP 주소나 주소 목록.

'*' 이면 모든 클라이언트를 허락한다.

Since version 0.2.
"""

OMX_PROFILE_INTERVAL = 0.001
"""OMX Profiler 의 실행 주기.

단위는 초(second) 다.

Since version 0.2.
"""

OMX_PROFILE_THRESHOLD = 0
"""OMX Profiler Threshold.

단위는 초(second) 다. 0 보다 큰 값으로 설정되면 실행된지 해당 시간이 흐른 요청만 기록된다.

Since version 0.2.
"""


def wsgi():
    """WSGI 애플리케이션을 제공하는 함수..

    ``Oliverfile`` 에서 새로 정의할 수 있다.

    Since 0.2.
    """
    pass


def main():
    """애플리케이션 코드를 제공하는데 사용하는 함수.

    ``Oliverfile`` 에서 새로 정의할 수 있다.
    
    주로 애플리케이션이 실행될 때 활성화될 모듈들을 import 하는데 사용된다. 기본 구현은 Oliver 가 제공하는 모든 모듈들을 import 한다.

    Since 0.2.
    """
    pass
